@@ -1,8 +1,9 @@
+chembox_template = """iupac, other_1\ncas_no, chemspider, chebi, chembl, ec_no, inchi, inchi_key, smiles, pubchem_cid, unii\nformula, title\n"""
 chembox_part_1 ="""
 {{Chembox
 | ImageFile = <!-- svg.svg -->
-| ImageFile_Ref	= 
-| ImageAlt = 
+| ImageFile_Ref	=
+| ImageAlt =
 | ImageSize = <!-- 244 (any number) -->
 | IUPACName = %s
 | OtherNames = {{Unbulleted list
@@ -13,24 +14,24 @@ chembox_part_2 = """
 | Section1={{Chembox Identifiers
 | index_label =  <!-- name -->
 | CASNo = %s
-| CASNo_Ref = 
+| CASNo_Ref =
 | ChemSpiderID = %s
-| ChemSpiderID_Ref = 
+| ChemSpiderID_Ref =
 | ChEBI = %s
 | ChEMBL = %s
 | EC_number = %s
-| EC_number_Comment = 
+| EC_number_Comment =
 | StdInChI = %s
-| StdInChIKey = %s 
+| StdInChIKey = %s
 | SMILES = %s
 | PubChem = %s
 | UNII = %s
-| UNII_Ref = 
+| UNII_Ref =
  }}
 """.lstrip('\n')
 chembox_part_3 ="""
 |Section2={{Chembox Properties
-| %s 
+| %s
  }}
 }}
 
@@ -42,9 +43,9 @@ chembox_part_3 ="""
 == References ==
 {{Reflist}}
 
-[[Category:Indole alkaloids]]
-
-{{Alkaloid-stub}}
 """.lstrip('\n')
+chembox_part_4 = """
+%s
 
-chembox_template = """iupac, other_1\ncas_no, chemspider, chebi, chembl, ec_no, inchi, inchi_key, smiles, pubchem_cid, unii\nformula, title\n"""
+%s
+""".lstrip('\n')
